@@ -26,10 +26,6 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("khangman"));
-    QApplication::setApplicationName(QStringLiteral("khangman"));
-    QApplication::setApplicationVersion(QStringLiteral(KHANGMAN_VERSION_STRING));
-    QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("khangman")));
 
     app.connect(&app, &QGuiApplication::lastWindowClosed, &app, &QCoreApplication::quit);
 
@@ -38,7 +34,9 @@ int main(int argc, char **argv)
                          QStringLiteral(KHANGMAN_VERSION_STRING),
                          i18n("Classical hangman game by KDE"),
                          KAboutLicense::GPL,
-                         i18n("(c) 2001-2011, Anne-Marie Mahfouf"));
+                         i18n("(c) 2001-2011, Anne-Marie Mahfouf"),
+                         QString(),
+                         QStringLiteral("https://apps.kde.org/khangman"));
     aboutData.addAuthor(i18n("Primoz Anzur"), i18n("Previous maintainer"),
             QStringLiteral("zerokode@gmx.net"));
 
@@ -108,6 +106,7 @@ int main(int argc, char **argv)
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("khangman")));
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
